package com.ruoyi.project.document.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.document.domain.TPlantproglistFile;

/**
 * 装置程序清单附件Mapper接口
 * 
 * @author ruoyi
 * @date 2020-12-05
 */
public interface TPlantproglistFileMapper 
{
    /**
     * 查询装置程序清单附件
     * 
     * @param id 装置程序清单附件ID
     * @return 装置程序清单附件
     */
    public TPlantproglistFile selectTPlantproglistFileById(Long id);

    /**
     * 查询装置程序清单附件列表
     * 
     * @param tPlantproglistFile 装置程序清单附件
     * @return 装置程序清单附件集合
     */
    @DataScope(deptAlias = "d")
    public List<TPlantproglistFile> selectTPlantproglistFileList(TPlantproglistFile tPlantproglistFile);

    /**
     * 新增装置程序清单附件
     * 
     * @param tPlantproglistFile 装置程序清单附件
     * @return 结果
     */
    public int insertTPlantproglistFile(TPlantproglistFile tPlantproglistFile);

    /**
     * 修改装置程序清单附件
     * 
     * @param tPlantproglistFile 装置程序清单附件
     * @return 结果
     */
    public int updateTPlantproglistFile(TPlantproglistFile tPlantproglistFile);

    /**
     * 删除装置程序清单附件
     * 
     * @param id 装置程序清单附件ID
     * @return 结果
     */
    public int deleteTPlantproglistFileById(Long id);

    /**
     * 批量删除装置程序清单附件
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTPlantproglistFileByIds(Long[] ids);
}
